from typing import Any

from django.conf import settings
from django.utils.module_loading import import_string

SIMPLE_PERMS_MODULE_NAME = getattr(settings, "SIMPLE_PERMS_MODULE_NAME", "perms")
SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION = getattr(settings, "SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION", None)
if SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION:
    SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION = import_string(SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION)
else:

    def SIMPLE_PERMS_GLOBAL_DEFAULT_PERMISSION(user, obj: Any, perm: str):  # noqa: N802
        return False



from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from simple_perms.logic import PermissionLogic


_registry: dict[str, "PermissionLogic"] = {}


def register(app_label: str, logic_class: "PermissionLogic  | None" = None):
    # In case not logic_class given, we suppose we are
    if not logic_class:

        def decorator(cls):
            register(app_label, cls)
            return cls

        return decorator

    if app_label in _registry:
        raise AttributeError(f'The "{app_label}" app is already registered by simple_perms')
    _registry[app_label] = logic_class()
    return None


def get_app_logic(app_label: str) -> "PermissionLogic":
    return _registry.get(app_label)
